==> luminarycloud-0.2.3-py3-none-any.whl: luminarycloud/_helpers/create_simulation.py <==
# Copyright 2023-2024 Luminary Cloud, Inc. All Rights Reserved.
import logging
from os import PathLike
from typing import Optional, Union

from google.protobuf import json_format

from .._proto.fvm.param_pb2 import Param as FvmParam
from .._proto.client.simulation_pb2 import SimulationParam
from .._proto.simulation.simulation_pb2 import (
    Simulation,
    SimulationOptions,
    CreateSimulationRequest,
)
from .._client import Client

logger = logging.getLogger(__name__)


def create_simulation(
    client: Client,
    *,
    project_id: str = "",
    mesh_id: str = "",
    name: str = "",
    simulation_params_json_path: Optional[Union[PathLike, str]] = None,
    batch_processing: bool = False,
) -> Simulation:

    if simulation_params_json_path is None:
        msg = "Missing simulation params json path."
        logger.exception(msg)
        raise ValueError(msg)

    logger.debug(f"Reading simulation params from file: {simulation_params_json_path}")
    with open(simulation_params_json_path) as fp:
        params_json = fp.read()

    # try to parse the json against each of the supported param types
    fvm_param, simulation_param = None, None
    try:
        fvm_param = json_format.Parse(params_json, FvmParam())
    except Exception as e:
        logger.debug(f"Unable to parse {simulation_params_json_path} as FvmParam: {e}")
        try:
            simulation_param = json_format.Parse(params_json, SimulationParam())
        except Exception as e:
            logger.debug(f"Unable to parse {simulation_params_json_path} as SimulationParam: {e}")
            # The json is invalid or is not one of  the supported types (fvm params
            # or client simulation params).
            raise ValueError(
                f"Failed to parse {simulation_params_json_path}. "
                + "Ensure JSON is valid and was downloaded using the "
                + "'Download simulation parameters JSON (API use only)' "
                + "option from the Luminary web app."
            )

    logger.debug(
        f"Calling gRPC CreateSimulation with project_id {project_id}, mesh_id "
        + f"{mesh_id}, fvm_param {fvm_param is not None}, simulation_param "
        + f"{simulation_param is not None}"
    )
    response = client.CreateSimulation(
        CreateSimulationRequest(
            project_id=project_id,
            mesh_id=mesh_id,
            name=name,
            simulation_options=SimulationOptions(batch_processing=batch_processing),
            # one of these will be None (can't assign the fields after creating
            # the request object, so have to do it this way)
            fvm_param=fvm_param,
            simulation_param=simulation_param,
        )
    )
    return response.simulation

==> luminarycloud-0.3.0-py3-none-any.whl: luminarycloud/_helpers/create_simulation.py <==
# Copyright 2023-2024 Luminary Cloud, Inc. All Rights Reserved.
import logging
from os import PathLike
from typing import Optional, Union

from google.protobuf import json_format

from .._proto.fvm.param_pb2 import Param as FvmParam
from .._proto.client.simulation_pb2 import SimulationParam
from .._proto.simulation.simulation_pb2 import (
    Simulation,
    SimulationOptions,
    CreateSimulationRequest,
)
from .._client import Client

logger = logging.getLogger(__name__)


def create_simulation(
    client: Client,
    *,
    project_id: str = "",
    mesh_id: str = "",
    name: str = "",
    simulation_params_json_path: Optional[Union[PathLike, str]] = None,
    batch_processing: bool = False,
) -> Simulation:

    if simulation_params_json_path is None:
        msg = "Missing simulation params json path."
        logger.exception(msg)
        raise ValueError(msg)

    logger.debug(f"Reading simulation params from file: {simulation_params_json_path}")
    with open(simulation_params_json_path) as fp:
        params_json = fp.read()

    simulation_param = None
    try:
        simulation_param = json_format.Parse(params_json, SimulationParam())
    except Exception as e:
        logger.debug(f"Unable to parse {simulation_params_json_path} as SimulationParam: {e}")
        raise ValueError(
            f"Failed to parse {simulation_params_json_path}. "
            + "Ensure JSON is valid and was downloaded using the "
            + "'Download simulation parameters JSON (API use only)' "
            + "option from the Luminary web app."
        )

    logger.debug(f"Calling gRPC CreateSimulation with project_id {project_id}, mesh_id {mesh_id}")
    response = client.CreateSimulation(
        CreateSimulationRequest(
            project_id=project_id,
            mesh_id=mesh_id,
            name=name,
            simulation_options=SimulationOptions(batch_processing=batch_processing),
            simulation_param=simulation_param,
        )
    )
    return response.simulation
